@@ -2,23 +2,15 @@
 """
 from __future__ import annotations
 
-import base64
-import ctypes
-import json
 import sys
-from functools import lru_cache as cache
 from functools import partial
-from typing import Any
 
 import multiprocessing
 from multiprocessing.queues import SimpleQueue as _SimpleQueue
-from pathlib import Path
 from pickle import PicklingError
 from typing import Callable
 from typing import TypeVar
 
-from .config import Config
-
 
 GRADIO_VERSION_ERROR_MESSAGE = "Make sure Gradio version is at least 3.46"
 
@@ -26,17 +18,6 @@ GRADIO_VERSION_ERROR_MESSAGE = "Make sure Gradio version is at least 3.46"
 T = TypeVar('T')
 
 
-@cache
-def self_cgroup_device_path() -> str:
-    cgroup_content = Path(Config.zerogpu_proc_self_cgroup_path).read_text()
-    for line in cgroup_content.strip().split('\n'):
-        contents = line.split(':devices:')
-        if len(contents) != 2:
-            continue # pragma: no cover
-        return contents[1]
-    raise Exception # pragma: no cover
-
-
 if sys.version_info.minor < 9: # pragma: no cover
     _SimpleQueue.__class_getitem__ = classmethod(lambda cls, _: cls) # type: ignore
 
@@ -79,13 +60,4 @@ def gradio_request_var():
     return LocalContext.request
 
 
-def malloc_trim():
-    ctypes.CDLL("libc.so.6").malloc_trim(0)
-
-
 debug = partial(print, 'SPACES_ZERO_GPU_DEBUG')
-
-
-def jwt_payload(token: str) -> dict[str, Any]:
-    _, payload, _ = token.split('.')
-    return json.loads(base64.urlsafe_b64decode(f'{payload}=='))
