@@ -1,11 +1,6 @@
 """
 """
 
-import shutil
-
-from pathlib import Path
-
-from .. import utils
 from ..config import Config
 
 
@@ -15,10 +10,12 @@ if Config.zero_gpu:
     from . import decorator
     from . import gradio
     from . import torch
+    from . import utils
 
     if torch.is_in_bad_fork():
         raise RuntimeError(
-            "CUDA has been initialized before importing the `spaces` package"
+            "CUDA has been initialized before importing the `spaces` package. "
+            "Try importing `spaces` before any other CUDA-related package."
         )
 
     def startup():
@@ -33,7 +30,3 @@ if Config.zero_gpu:
 
     torch.patch()
     gradio.one_launch(startup)
-
-    # Cleanup offload directory
-    shutil.rmtree(Config.zerogpu_offload_dir, ignore_errors=True)
-    Path(Config.zerogpu_offload_dir).mkdir(parents=True)
